I created this project on github back in 2011 and abandoned it. Since then I've written the uposatha-ical package
and have only just returned as of Jan 2023. I notice now that I received a pull request in 2014!

At this time I'm writing the code myself and would prefer to keep it that way. Perhaps down the line I might encourage
changes. However, if you notice anything that could be improved feel free to raise an issue. This is especially 
important if there's a problem in generating the calendar dates. 

Many thanks,

Ajahn Jhanarato
Kusala Hermitage 
6th Jan 2023